clobber_globals

Function clobber_globals 

pub fn clobber_globals()
Replace all mutable global data with arbitrary values. This is used at the start of tests to ensure that the property holds in any context.