pub struct MethodSpec { /* private fields */ }Expand description
The specification of a function. This can be used when verifying callers of the function to avoid simulating the entire function itself.
Implementations
Sourceimpl MethodSpec
impl MethodSpec
Sourcepub fn enable(&self)
pub fn enable(&self)
Enable this MethodSpec to be used as an override for its subject function.
pub fn pretty_print(&self) -> &'static str